@@ -13,13 +13,16 @@ class UserSerializer(serializers.ModelSerializer):
     User serializer
     """
 
-    email = serializers.EmailField(
-        validators=[UniqueValidator(queryset=get_all_users(),
-                                    message=_('User with this email already exists.'))])
-    username = serializers.CharField(validators=[UniqueValidator(
-        queryset=get_all_users(),
-        message=_('User with this username already exists.')
-    )])
+    if 'email' in drfr_settings.USER_FIELDS:
+        email = serializers.EmailField(
+            validators=[UniqueValidator(queryset=get_all_users(),
+                                        message=_('User with this email already exists.'))])
+
+    if 'username' in drfr_settings.USER_FIELDS:
+        username = serializers.CharField(validators=[UniqueValidator(
+            queryset=get_all_users(),
+            message=_('User with this username already exists.')
+        )])
 
     if enable_has_password():
         has_password = serializers.SerializerMethodField()
